@@ -26,7 +26,7 @@ class TestOsmApiHelper(osmapi_tests.TestOsmApi):
         self.api._username = 'testuser'
         self.api._password = 'testpassword'
 
-    def test_passwordfile(self):
+    def test_passwordfile_only(self):
         path = os.path.join(
             __location__,
             'fixtures',
@@ -36,6 +36,16 @@ class TestOsmApiHelper(osmapi_tests.TestOsmApi):
         self.assertEquals('testosm', my_api._username)
         self.assertEquals('testpass', my_api._password)
 
+    def test_passwordfile_with_user(self):
+        path = os.path.join(
+            __location__,
+            'fixtures',
+            'passwordfile.txt'
+        )
+        my_api = osmapi.OsmApi(username='testuser', passwordfile=path)
+        self.assertEquals('testuser', my_api._username)
+        self.assertEquals('testuserpass', my_api._password)
+
     def test_http_request_get(self):
         response = self.api._http_request(
             'GET',
@@ -101,19 +111,16 @@ class TestOsmApiHelper(osmapi_tests.TestOsmApi):
 
     def test_http_request_410_response(self):
         self.setupMock(410)
-        response = self.api._http_request(
-            'GET',
-            '/api/0.6/test410',
-            False,
-            None
-        )
-        self.api._session.request.assert_called_with(
-            'GET',
-            self.api_base + '/api/0.6/test410',
-            auth=None,
-            data=None
-        )
-        self.assertIsNone(response, "test response")
+        with self.assertRaises(osmapi.ElementDeletedApiError) as cm:
+            self.api._http_request(
+                'GET',
+                '/api/0.6/test410',
+                False,
+                None
+            )
+        self.assertEquals(cm.exception.status, 410)
+        self.assertEquals(cm.exception.reason, "test reason")
+        self.assertEquals(cm.exception.payload, "test response")
 
     def test_http_request_500_response(self):
         self.setupMock(500)
