@@ -65,13 +65,8 @@ class TestOsmApiWay(osmapi_tests.TestOsmApi):
     def test_WayGet_nodata(self):
         self._session_mock()
 
-        result = self.api.WayGet(321)
-
-        args, kwargs = self.api._session.request.call_args
-        self.assertEquals(args[0], 'GET')
-        self.assertEquals(args[1], self.api_base + '/api/0.6/way/321')
-
-        self.assertEquals(result, '')
+        with self.assertRaises(osmapi.ResponseEmptyApiError):
+            self.api.WayGet(321)
 
     def test_WayCreate(self):
         self._session_mock(auth=True)
@@ -251,6 +246,12 @@ class TestOsmApiWay(osmapi_tests.TestOsmApi):
         self.assertEquals(result[16]['data']['changeset'], 298)
         self.assertEquals(result[16]['type'], 'way')
 
+    def test_WayFull_invalid_response(self):
+        self._session_mock()
+
+        with self.assertRaises(osmapi.XmlResponseInvalidError):
+            self.api.WayFull(321)
+
     def test_WaysGet(self):
         self._session_mock()
 
